type WindowsPath = Pattern[/\A(([a-zA-Z]:[\\\/])|([\\\/][\\\/][^\\\/]+[\\\/][^\\\/]+)|([\\\/][\\\/]\?[\\\/][^\\\/]+)).*\z/]
type ShortcutPath = Pattern[/\.[lL][nN][kK]$/]

# @summary Creates a Windows shortcut
#
# @param target The target path of the shortcut.
# @param path The path to the shortcut file. Defaults to the title of the resource.
# @param arguments Additional arguments to pass to the target as a string.
# @param description The description of the shortcut.
# @param icon_location The path to the icon file.
# @param working_directory The working directory of the shortcut.
define windows::shortcut (
  # The target path of the shortcut.
  WindowsPath $target,
  ShortcutPath $path  = $title,
  String $arguments         = undef,
  String $description       = undef,
  String $icon_location     = undef,
  WindowsPath $working_directory = undef,
) {
  exec { "windows-shortcut-${path}":
    command  => template('windows/shortcut.ps1.erb'),
    creates  => $path,
    provider => 'powershell',
  }
}
